***************************************************************************
*This file will examine how arrests (as opposed) to offenders vary
*with school calendar information.  If there are multiple offenses for
*a single incident code--each offense is counted separately.
***************************************************************************

# delimit ;

capture log close;
capture macro drop _all;
capture program drop _all;
set mem 350m;
set matsize 700;
set more off;

*Set macros depending on which machine the program is running;
 
global dweath "c:\projects\crime\data\weather";
global dsch "c:\projects\crime\data\schoolcalendars";
global dcrime "c:\projects\crime\school\revised";
global dnibrs "c:\projects\crime\data\nibrs";

/*
 global dsch "d:\sch_crime\data";
 global dcrime "d:\sch_crime\data";
 global dnibrs "d:\nibrsdata";
 global dtable "d:\sch_crime\tables";
*/

 cd ${dcrime};
 log using "${dcrime}\arrests_school.log", replace;
/*
************************;
*** Group A Offenses ***;
************************;

program define arrest;

****************************************************************************************;
*Read in administrative data file which contains incident information.  Not all of the
*oris listed have school data so I'm going to create a list that contains only those
*oris that we have calendar data for.  This will speed up the program.;
****************************************************************************************;


use V1003 V1004 V1005 V1006 V1007 if 
    V1003=="ID0100200" | V1003=="UT0060300" |
    V1003=="UT0030100" | V1003=="ID0140200" |
    V1003=="ID0420200" | V1003=="UT0180500" |
    V1003=="UT0182500" | V1003=="SC0230200" |
    V1003=="CO0010500" | V1003=="IA0070300" |
    V1003=="CO0010100" | V1003=="CO0210100" |
    V1003=="CO0300400" | V1003=="ID0010100" |
    V1003=="IA0570100" | V1003=="IA0770300" |
    V1003=="IA0820200" | V1003=="MA0071800" |
    V1003=="MA0146000" | V1003=="OH0570200" |
    V1003=="OH0770100" | V1003=="OHCIP0000" |
    V1003=="SC0400100" | V1003=="TX2270100" |
    V1003=="UT0250600" | V1003=="VA1160000" |
    V1003=="IA0520200" | V1003=="ND0510200" |
    V1003=="ND0090200"
using ${dnibrs}\nibrs`1'_adm.dta;


 rename V1003 ori;
 rename V1004 incnum;
 rename V1005 incdate;
 rename V1006 repdate;
 rename V1007 ihour;
 
 
 gen year=real(substr(incdate,1,4));
   label variable year "year of incident";
 gen month=real(substr(incdate,5,2));
   label variable month "month of incident";
 gen day=real(substr(incdate,7,2));
   label variable day "day of incident";
 gen idate=mdy(month,day,year);
 
*Merge on city indicator from batch 1 files;

 mmerge ori using "${dnibrs}\nibrs`1'_bh1.dta", type(n:n) unmatched(master) umatch(B1003)
    ukeep(B1012) urename(B1012 oritype);

 tab oritype, missing;
	***Note: we are indeed getting only cities;
	

*Merge on incident data from offense (aka incident) files - Segment 2;
*Note that there are often multiple offense records associated with one incident record;

 mmerge ori incnum using "${dnibrs}\nibrs`1'_inc.dta", type(1:n) umatch(V2003 V2004)
 unmatched(master) ukeep(V2006) urename (V2006 ucrcode);

********************************************************************************;
*About 10-20% of incidents have dates that correspond to reporting and not occurence;
*We will only examine incidents that occured on the incident date--not incidents
*that were reported on the incident date so we drop the other observations;
********************************************************************************;
 
tab repdate, missing;
keep if repdate=="";
drop _merge repdate;
drop if ori=="";

***************************;
***Merge on arrest data****;
***************************;

mmerge ori incnum using ${dnibrs}\nibrs`1'_arr.dta, type(n:n) umatch(V6003 V6004) 
   unmatched(master) ukeep (V6006 V6008 V6011 V6014)
   urename(V6006 seqnum \ V6008 arrdate \ V6011 ucrarr \ V6014 aage );

 gen noage=aage==0 if aage!=.;
 tab noage, missing;
 replace aage=. if aage==0;
 drop noage;
 
*Create a variable to capture age at the time of the incident (iage) rather than at
*the time of the arrest;

 gen ayear=real(substr(arrdate,1,4));
   label variable year "year of incident";
 gen amonth=real(substr(arrdate,5,2));
   label variable month "month of incident";
 gen aday=real(substr(arrdate,7,2));
   label variable day "day of incident";
 gen adate=mdy(amonth,aday,ayear);

 gen iage=aage if idate==adate;

**Brian I changed the next line to int instead of round.  I think it makes more sense.;

 replace iage=int(aage+0.5-((adate-idate)/365));
 replace iage=aage if iage>aage & iage~=.;

 compress;
 doub2flt _all;
 desc;
 keep ori year month day idate incnum ucrcode iage;
 
 save ${dcrime}\arrest`1'.dta, replace;
 clear;
 
 end;
 
 **;

 arrest 95 1995;
 arrest 96 1996;
 arrest 97 1997;
 arrest 98 1998;
 arrest 99 1999;
*/
***************************;
*** All Offenses       ****;
***************************;

*Now we append the files from all years together. One incident may be listed in two years
 if an arrest was made in the year following the incident.  The record from the year of the
 arrest will have all relevant information, including the correct incident date, so simply
 take this record.  This essentially involves taking the record with the most recent year;


 use ${dcrime}\arrest95.dta;
 for num 96/99: append using arrestX.dta;

 egen tmp=nvals(year), by(ori incnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;
 

compress;
doub2flt _all;

*** Create Arrest Data ***;

 gen juv=iage>=5 & iage<18 & iage~=.;
 gen adlt=iage>=18 & iage~=.; 

 gen byte viol=ucrcode=="13A" | ucrcode=="13B" | ucrcode=="13C" | ucrcode=="09A" | ucrcode=="09B"
    | ucrcode=="09C" | ucrcode=="100" | ucrcode=="11A" | ucrcode=="11B" | ucrcode=="11C" 
    | ucrcode=="11D" | ucrcode=="36A" | ucrcode=="36B";


 gen byte prop=ucrcode=="510" | ucrcode=="220" | ucrcode=="250" | ucrcode=="290" | ucrcode=="210" 
    | ucrcode=="270" | ucrcode=="26A" | ucrcode=="26B" | ucrcode=="26C"
    | ucrcode=="26D" | ucrcode=="26E" | ucrcode=="23A" | ucrcode=="23B" | ucrcode=="23C"
    | ucrcode=="23D" | ucrcode=="23E" | ucrcode=="23F" | ucrcode=="23G" | ucrcode=="23H"
    | ucrcode=="240" | ucrcode=="120" | ucrcode=="280";



  gen byte crimea=1;

  gen byte otha=crimea-viol-prop;

  for any viol prop crimea otha:
     gen byte j_X=juv*X \
     gen byte a_X=adlt*X ;

  collapse (sum) j_* a_* , by(ori year month day);

*** Label Cities ***;

    gen str20 city="";
    
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

    label variable city "city";


  gen date = mdy(month, day, year);
  format date %d;
  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var j_* a_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";

*Create other variables;

 for any sun tue wed thu fri sat \ any 0 2 3 4 5 6: gen byte dd_X=dow(date)==Y;
 
 egen cmy=group(city month year);

 for num 1996/1999: gen byte yyX=year==X;

*Merge on population information;

 mmerge ori year using "${dnibrs}\pop9599.dta", type(n:1) unmatched(master) ukeep(ori year pop);
 sum pop, det;
 drop _merge;


******************************************************************************
*Merge on Calendar Information.
******************************************************************************;

 mmerge city year month day using "${dsch}\finalcalendars.dta", type(n:1)
    umatch(city year month day);


 
 **********************;
 ***Create Variables***;
 **********************;

*I get rid of the observations occuring before the month of the first school day.;

 gen flag=firstday*date;
 egen startsamp=min(flag), by(city);
 gen startmn=month(startsamp);
 gen startyr=year(startsamp);
 drop if year<startyr | (year==startyr & month<startmn);

 drop flag startsamp startmn startyr;

*Create indicator for the summers of 1996, 1997, 1998, 1999, 2000 and 2001;

 gen fday9495=mdy(month,day,year) if firstday==1&year==1994; 
 gen lday9495=mdy(month,day,year) if lastday==1&year==1995;

 gen fday9596=mdy(month,day,year) if firstday==1&year==1995; 
 gen lday9596=mdy(month,day,year) if lastday==1&year==1996;
 
 gen fday9697=mdy(month,day,year) if firstday==1&year==1996; 
 gen lday9697=mdy(month,day,year) if lastday==1&year==1997;
 
 gen fday9798=mdy(month,day,year) if firstday==1&year==1997; 
 gen lday9798=mdy(month,day,year) if lastday==1&year==1998;
 
 gen fday9899=mdy(month,day,year) if firstday==1&year==1998; 
 gen lday9899=mdy(month,day,year) if lastday==1&year==1999;
 
 gen fday9900=mdy(month,day,year) if firstday==1&year==1999; 
 gen lday9900=mdy(month,day,year) if lastday==1&year==2000;
 
 gen fday0001=mdy(month,day,year) if firstday==1&year==2000; 
 gen lday0001=mdy(month,day,year) if lastday==1&year==2001;
 
 gen fday0102=mdy(month,day,year) if firstday==1&year==2001; 
 gen lday0102=mdy(month,day,year) if lastday==1&year==2002;


 for any 9495 9596 9697 9798 9899 9900 0001 0102: 
 	egen fdtX=max(fdayX), by(city) \ egen ldtX=max(ldayX), by(city);

 
 gen summer=(date>ldt9495&date<fdt9596) | (date<fdt9596 & ldt9495==.) if fdt9596~=.; 
 replace summer=0 if (date>=fdt9596 & date<=ldt9596) & ldt9596~=.;
 replace summer=1 if (date>ldt9596&date<fdt9697) | (date<fdt9697 & ldt9596==.) & fdt9697~=.; 
 replace summer=0 if (date>=fdt9697 & date<=ldt9697) & ldt9697~=.;
 replace summer=1 if (date>ldt9697&date<fdt9798) | (date<fdt9798 & ldt9697==.) & fdt9798~=.; 
 replace summer=0 if (date>=fdt9798 & date<=ldt9798) & ldt9798~=.;
 replace summer=1 if (date>ldt9798&date<fdt9899) | (date<fdt9899 & ldt9798==.) & fdt9899~=.; 
 replace summer=0 if (date>=fdt9899 & date<=ldt9899) & ldt9899~=.;
 replace summer=1 if (date>ldt9899&date<fdt9900) | (date<fdt9900 & ldt9899==.) & fdt9900~=.; 
 replace summer=0 if (date>=fdt9900 & date<=ldt9900) & ldt9900~=.;
 replace summer=1 if (date>ldt9900&date<fdt0001) | (date<fdt0001 & ldt9900==.) & fdt0001~=.; 
 replace summer=0 if (date>=fdt0001 & date<=ldt0001) & ldt0001~=.;
 capture replace summer=1 if (date>ldt00001&date<fdt0102) | (date<fdt0102 & ldt0001==.) & fdt0102~=.; 
 capture replace summer=0 if (date>=fdt0102 & date<=ldt0102) & ldt0102~=.;

     ***summer variables will be missing when we do not have school calendar info;
  

 for any holiday inservice break: replace X=0 if X==.;
 
 gen nosch=inservice==1|holiday==1|break==1|summer==1;
 

  drop if city=="Akron, OH" & year<1999;
  drop if city=="Anderson, SC" & year==1995 & (month==11|month==12);
  drop if city=="Aurora, CO" & year<1997;
  drop if city=="Austin, TX" & year<1998;
  drop if city=="Beaufort, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Boise, ID" & year<1995 ;
  drop if city=="Cedar Rapids, IA" & year<1999;
  drop if city=="Charleston, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Cincinnati, OH" & year<1998;
  drop if city=="Clarksville, TN" & year<1998;
  drop if city=="Colorado Springs, CO" & year<1997;
  drop if city=="Columbia, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Council Bluffs, IA" & year<1998;
  drop if city=="Davenport, IA" & year==1996 & month==7;
  drop if city=="Dayton, OH" & year<1998;
  drop if city=="Des Moines, IA" & year<1995;
  drop if city=="Florence, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Greenville, SC" & year<1995;
  drop if city=="Jackson, MI" & year<1997;
  drop if city=="Lakewood, CO" & year<1997;
  drop if city=="Myrtle Beach, SC" & year==1995 & (month==11|month==12);
  drop if city=="Newport News, VA" & (year<1998 | (year==1998 & month<7));
  drop if city=="Orangeburg, SC" & year==1995 & (month==11|month==12);
  drop if city=="Petersburg, VA" & ((year==1995 & month<10)|(year==1999 & month==6));
  drop if city=="Provo, UT" & year<1995;
  drop if city=="Sandy, UT" & year<1995;
  drop if city=="Sioux City, IA" & year<1995;
  drop if city=="Southfield, MI" & (year<1996 | (year==1996 & month<5)); 
  drop if city=="Spartanburg, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Springfield, MA" & (year<1996 | (year==1996 & month<6));
  drop if city=="Sterling Heights, MI" & year==1995 & month<3;
  drop if city=="Waterloo, IA" & ((year==1996 & month<8) | year<1996);
  drop if city=="West Valley, UT" & ((year==1998 & month<8) | year<1998);
  drop if city=="Westminster, CO" & ((year==1999 & month==1) | (year==1998 & month==12)
     | (year==1997 & month>3) | year<1997);
  drop if city=="Worcester, MA" & year<1995;
  drop if city=="Idaho Falls, ID" & year<1995;
  drop if city=="Nampa, ID" & year<1995;
  drop if city=="Twin Falls, ID" & year<1995;
  drop if city=="Layton, UT" & ((year==1999 & month>=3 & month<=5) | (year==1998 & month>=7)
     | (year==1996 & month==9) | (year==1995 & month>=7 & month<=8) | (year==1995 & month<9)
     | year<1995);
  drop if city=="Logan, UT" & ((year==1999 & month==12) | (year==1998 & month>=11) | year<1995);
  drop if city=="Nampa, ID" & (year==1995 & (month==11 | month==12));
  drop if city=="Iowa City, IA" & (year<1996 | (year==1996 & month<8)); **Calendar data missing 1995/1996;
  drop if city=="Minot, ND" & (year==1995 & (month==11 | month==12));
  drop if city=="Fargo, ND" & year<1995;
  drop if summer==.;

*I will keep only those observations with offender data;
 keep if j_viol~=.;

 drop fdt* ldt* fday* lday* _merge;
 

 sum;
 desc;
 compress;
 doub2flt _all;
 
save ${dcrime}\school_arrests.dta, replace;
log close;

**;

