***************************************************************************
*This file generates the tables for the paper.
***************************************************************************

# delimit ;

capture log close;
capture macro drop _all;
capture program drop _all;
set mem 450m;
set matsize 700;
set more off;

*Set macros depending on which machine the program is running;
 

 global ducr "c:\projects\crime\data\ucr"; 
 global dweath "c:\projects\crime\data\weather";
 global dsch "c:\projects\crime\data\schoolcalendars";
 global dcrime "c:\projects\crime\school\revised";
 global dnibrs "c:\projects\crime\data\nibrs";
 global dtable "c:\projects\crime\school\revised";


 /*
 global ducr "d:\ucrdata";
 global dsch "d:\sch_crime\data";
 global dcrime "d:\sch_crime\data";
 global dnibrs "d:\nibrsdata";
 global dtable "d:\sch_crime\tables";
*/

 log using ${dtable}\table8.log, replace;
 
 
 ***********************************************************;
 * This ado file defines the inservice and break variables *;
 ***********************************************************;
 
 program define inservice;
 
   egen cty_cd=group(city);
   tsset cty_cd date;

   **Set breaks and holidays to zero for half days;
   for var break holiday: replace X=0 if half==1;
   replace half=0 if half==.;
 
   **All inservice days;
   gen inservice7=inservice;
   gen break7=break;
   count if inservice7==1;
   
   **Getting rid of half days;
   replace inservice7=0 if half==1;
   count if inservice7==1;
 
   **Getting rid of days when any school district has a holiday;
   egen tmpvar=max(holiday), by(date);
   replace break7=1 if inservice7==1 & tmpvar==1;
   replace inservice7=0 if tmpvar==1;
   count if inservice7==1;
   drop tmpvar;
 
   **Getting rid of days within a week of a holiday;
   gen tmpvar=1 if inservice7==1 &  (l1.holiday==1 | l2.holiday==1 | l3.holiday==1 |
     l4.holiday==1 | l5.holiday==1 | l6.holiday==1 | l7.holiday==1 | f1.holiday==1 |
     f2.holiday==1 | f3.holiday==1 | f4.holiday==1 | f5.holiday==1 | f6.holiday==1 |
     f7.holiday==1);
   replace inservice7=0 if tmpvar==1;
   replace break7=1 if tmpvar==1;
   drop tmpvar;
   count if inservice7==1;
 
   **Create idiosyncratic and regular break.;
   gen tmpvar1=break7+holiday;
   egen tmpvar2=mean(tmpvar1), by(date);
   gen i_break7=break7;
   replace i_break7=0 if tmpvar2>.3;
   replace break7=break7-i_break7;
   drop tmpvar* cty_cd;

 end;
 
**;


************************************************;
* This ado file merges on calendar information *;
************************************************;

program define calendar;

 mmerge city year month day using "${dsch}\finalcalendars.dta", type(n:1) umatch(city year month day);

 *I get rid of the observations occuring before the first school day.;

 gen flag=firstday*date;
 egen startsamp=min(flag), by(city);
 gen startmn=month(startsamp);
 gen startyr=year(startsamp);
 drop if year<startyr | (year==startyr & month<startmn);

 drop flag startsamp startmn startyr;

 *Create indicator for the summers of 1996, 1997, 1998, 1999, 2000 and 2001;

 gen fday9495=mdy(month,day,year) if firstday==1&year==1994; 
 gen lday9495=mdy(month,day,year) if lastday==1&year==1995;

 gen fday9596=mdy(month,day,year) if firstday==1&year==1995; 
 gen lday9596=mdy(month,day,year) if lastday==1&year==1996;
 
 gen fday9697=mdy(month,day,year) if firstday==1&year==1996; 
 gen lday9697=mdy(month,day,year) if lastday==1&year==1997;
 
 gen fday9798=mdy(month,day,year) if firstday==1&year==1997; 
 gen lday9798=mdy(month,day,year) if lastday==1&year==1998;
 
 gen fday9899=mdy(month,day,year) if firstday==1&year==1998; 
 gen lday9899=mdy(month,day,year) if lastday==1&year==1999;
 
 gen fday9900=mdy(month,day,year) if firstday==1&year==1999; 
 gen lday9900=mdy(month,day,year) if lastday==1&year==2000;
 

 for any 9495 9596 9697 9798 9899 9900: 
 	egen fdtX=max(fdayX), by(city) \ egen ldtX=max(ldayX), by(city);

*Create indicator variables for summer;

 gen summer=(date>ldt9495&date<fdt9596) | (date<fdt9596 & ldt9495==.) if fdt9596~=.; 
 replace summer=0 if (date>=fdt9596 & date<=ldt9596) & ldt9596~=.;
 replace summer=1 if (date>ldt9596&date<fdt9697) | (date<fdt9697 & ldt9596==.) & fdt9697~=.; 
 replace summer=0 if (date>=fdt9697 & date<=ldt9697) & ldt9697~=.;
 replace summer=1 if (date>ldt9697&date<fdt9798) | (date<fdt9798 & ldt9697==.) & fdt9798~=.; 
 replace summer=0 if (date>=fdt9798 & date<=ldt9798) & ldt9798~=.;
 replace summer=1 if (date>ldt9798&date<fdt9899) | (date<fdt9899 & ldt9798==.) & fdt9899~=.; 
 replace summer=0 if (date>=fdt9899 & date<=ldt9899) & ldt9899~=.;
 replace summer=1 if (date>ldt9899&date<fdt9900) | (date<fdt9900 & ldt9899==.) & fdt9900~=.; 
 replace summer=0 if (date>=fdt9900 & date<=ldt9900) & ldt9900~=.;

*Drop observations for which we do not have school calendar data;

 drop if summer==.;

   *NOTE: summer variables will be missing when we do not have school calendar info;

*Create indicator variables for all the reasons that a student might not have school;

 for any holiday inservice break half: replace X=0 if X==.;
 
 for any sun tue wed thu fri sat \ any 0 2 3 4 5 6: gen byte dd_X=dow(date)==Y;

 gen nosch=inservice==1|holiday==1|break==1|summer==1|dd_sat==1|dd_sun==1;

 replace nosch=0 if half==1;
 
 drop fdt* ldt*;

*Drop observations for which we do not have crime data;

  drop if city=="Akron, OH" & year<1999;
  drop if city=="Anderson, SC" & year==1995 & (month==11|month==12);
  drop if city=="Aurora, CO" & year<1997;
  drop if city=="Austin, TX" & year<1998;
  drop if city=="Beaufort, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Boise, ID" & year<1995 ;
  drop if city=="Cedar Rapids, IA" & year<1999;
  drop if city=="Charleston, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Cincinnati, OH" & year<1998;
  drop if city=="Clarksville, TN" & year<1998;
  drop if city=="Colorado Springs, CO" & year<1997;
  drop if city=="Columbia, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Council Bluffs, IA" & year<1998;
  drop if city=="Davenport, IA" & year==1996 & month==7;
  drop if city=="Dayton, OH" & year<1998;
  drop if city=="Des Moines, IA" & year<1995;
  drop if city=="Florence, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Greenville, SC" & year<1995;
  drop if city=="Jackson, MI" & year<1997;
  drop if city=="Lakewood, CO" & year<1997;
  drop if city=="Myrtle Beach, SC" & year==1995 & (month==11|month==12);
  drop if city=="Newport News, VA" & (year<1998 | (year==1998 & month<7));
  drop if city=="Orangeburg, SC" & year==1995 & (month==11|month==12);
  drop if city=="Petersburg, VA" & ((year==1995 & month<10)|(year==1999 & month==6));
  drop if city=="Provo, UT" & year<1995;
  drop if city=="Sandy, UT" & year<1995;
  drop if city=="Sioux City, IA" & year<1995;
  drop if city=="Southfield, MI" & (year<1996 | (year==1996 & month<5)); 
  drop if city=="Spartanburg, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Springfield, MA" & (year<1996 | (year==1996 & month<6));
  drop if city=="Sterling Heights, MI" & year==1995 & month<3;
  drop if city=="Waterloo, IA" & ((year==1996 & month<8) | year<1996);
  drop if city=="West Valley, UT" & ((year==1998 & month<8) | year<1998);
  drop if city=="Westminster, CO" & ((year==1999 & month==1) | (year==1998 & month==12)
     | (year==1997 & month>3) | year<1997);
  drop if city=="Worcester, MA" & year<1995;
  drop if city=="Idaho Falls, ID" & year<1995;
  drop if city=="Nampa, ID" & year<1995;
  drop if city=="Twin Falls, ID" & year<1995;
  drop if city=="Layton, UT" & ((year==1999 & month>=3 & month<=5) | (year==1998 & month>=7)
     | (year==1996 & month==9) | (year==1995 & month>=7 & month<=8) | (year==1995 & month<9)
     | year<1995);
  drop if city=="Logan, UT" & ((year==1999 & month==12) | (year==1998 & month>=11) | year<1995);
  drop if city=="Nampa, ID" & (year==1995 & (month==11 | month==12));
  drop if city=="Iowa City, IA" & (year<1996 | (year==1996 & month<8)); **Calendar data missing 1995/1996;
  drop if city=="Minot, ND" & (year==1995 & (month==11 | month==12));
  drop if city=="Fargo, ND" & year<1995;
  drop if summer==.;

  
end;

**;

**************************************************;
* This ado file creates a base offender data set *;
**************************************************;

program define baseoff;

*Merge together annual files with one obs per offender x incident;

 use ${dcrime}\groupa95.dta;
 for num 96/99: append using "${dcrime}\groupaX.dta";
 
*This drops duplicate observations (if an incident took place in one year, but the resulting arrest
 took place in another year, there will be observations in both years, but only the latest year will
 contain all relevant information.  Hence, only keep max year obs;
 
 egen tmp=nvals(year), by(ori incnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;

*Create indicators for violent and property crime;

 gen byte viol=ucrcode=="13A" | ucrcode=="13B" | ucrcode=="13C" | ucrcode=="09A" | ucrcode=="09B"
    | ucrcode=="09C" | ucrcode=="100" | ucrcode=="11A" | ucrcode=="11B" | ucrcode=="11C" 
    | ucrcode=="11D" | ucrcode=="36A" | ucrcode=="36B";

 gen byte prop=ucrcode=="510" | ucrcode=="220" | ucrcode=="250" | ucrcode=="290" | ucrcode=="210" 
    | ucrcode=="270" | ucrcode=="26A" | ucrcode=="26B" | ucrcode=="26C"
    | ucrcode=="26D" | ucrcode=="26E" | ucrcode=="23A" | ucrcode=="23B" | ucrcode=="23C"
    | ucrcode=="23D" | ucrcode=="23E" | ucrcode=="23F" | ucrcode=="23G" | ucrcode=="23H"
    | ucrcode=="240" | ucrcode=="120" | ucrcode=="280";


 gen byte groupb=ucrcode=="90A" |ucrcode=="90B" |ucrcode=="90C" |ucrcode=="90D" |ucrcode=="90E"
    |ucrcode=="90F" |ucrcode=="90G" |ucrcode=="90H" |ucrcode=="90I" |ucrcode=="90J" |ucrcode=="90Z" ;

 gen byte crimea=1-groupb;
 gen byte otha=crimea-viol-prop;

*Drop all observations for which we do not have age information;
 
 tab juv adlt, m;
 keep if juv==1|adlt==1;
 
*Create juvenile crime indicators;
 
 for any viol prop groupb crimea otha: gen j_X=X*juv;
  
*Create date variable;

 gen date = mdy(month, day, year);
 format date %d;

*Label cities;

    gen str20 city="";
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

*Label Offense Codes;

  gen str30 ucrname="";
  label var ucrname "UCR Offense Name";
  replace ucrname="Arson"					if ucrcode=="200";
  replace ucrname="Aggravated Assault"				if ucrcode=="13A";
  replace ucrname="Simple Assault"				if ucrcode=="13B";
  replace ucrname="Intimidation" 				if ucrcode=="13C";
  replace ucrname="Bribery"					if ucrcode=="510";
  replace ucrname="Burglary"					if ucrcode=="220";
  replace ucrname="Counterfeiting/Forgery" 			if ucrcode=="250";
  replace ucrname="Vandalism"				        if ucrcode=="290";
  replace ucrname="Drug/Narcotic Violations"			if ucrcode=="35A";
  replace ucrname="Drug Equipment Violations"			if ucrcode=="35B";
  replace ucrname="Embezzlement"				if ucrcode=="270";
  replace ucrname="Extortion/Blackmail" 			if ucrcode=="210";
  replace ucrname="False Pretenses/Swindle"			if ucrcode=="26A";
  replace ucrname="Credit Card/ATM Fraud"			if ucrcode=="26B";
  replace ucrname="Impersonation"				if ucrcode=="26C";
  replace ucrname="Welfare Fraud"				if ucrcode=="26D";
  replace ucrname="Wire Fraud"					if ucrcode=="26E";
  replace ucrname="Betting/Wagering"				if ucrcode=="39A";
  replace ucrname="Operating/Promote Gambling"			if ucrcode=="39B";
  replace ucrname="Gambling Equipment Violations"		if ucrcode=="39C";
  replace ucrname="Sports Tampering"				if ucrcode=="39D";
  replace ucrname="Murder/Nonnegligent Manslaughter"		if ucrcode=="09A";
  replace ucrname="Negligent Manslaughter"			if ucrcode=="09B";
  replace ucrname="Justifiable Homicide"			if ucrcode=="09C";
  replace ucrname="Kidnaping/Abduction"  			if ucrcode=="100";
  replace ucrname="Pocket-picking" 				if ucrcode=="23A";
  replace ucrname="Purse-snatching"				if ucrcode=="23B";
  replace ucrname="Shoplifting"				  	if ucrcode=="23C";
  replace ucrname="Theft From Building"		  		if ucrcode=="23D";
  replace ucrname="Theft From Coin-Operated Machine"		if ucrcode=="23E";
  replace ucrname="Theft From Motor Vehicle"			if ucrcode=="23F";
  replace ucrname="Motor Vehicle Theft - Parts"			if ucrcode=="23G";
  replace ucrname="All Other Larceny"				if ucrcode=="23H";
  replace ucrname="Motor Vehicle Theft"				if ucrcode=="240";
  replace ucrname="Pornography/Obscene Material"		if ucrcode=="370";
  replace ucrname="Prostitution"				if ucrcode=="40A";
  replace ucrname="Assist/Promote Prostitution"			if ucrcode=="40B";
  replace ucrname="Robbery"					if ucrcode=="120";
  replace ucrname="Forcible Rape"				if ucrcode=="11A";
  replace ucrname="Forcible Sodomy"				if ucrcode=="11B";
  replace ucrname="Sexual Assault With An Object"		if ucrcode=="11C";
  replace ucrname="Child Molestation"				if ucrcode=="11D";
  replace ucrname="Incest"					if ucrcode=="36A";
  replace ucrname="Statutory Rape"				if ucrcode=="36B";
  replace ucrname="Stolen Property Offense"			if ucrcode=="280";
  replace ucrname="Weapon Law Violations"			if ucrcode=="520";
  replace ucrname="Bad Checks"					if ucrcode=="90A";
  replace ucrname="Curfew, Loitering, and Vagrancy"		if ucrcode=="90B";
  replace ucrname="Disorderly Conduct"				if ucrcode=="90C";
  replace ucrname="Driving Under the Influence"			if ucrcode=="90D";
  replace ucrname="Drunkenness"					if ucrcode=="90E";
  replace ucrname="Family Offenses, Nonviolent"			if ucrcode=="90F";
  replace ucrname="Liquor Law Violations"			if ucrcode=="90G";
  replace ucrname="Peeping Tom"					if ucrcode=="90H";
  replace ucrname="Runaway"					if ucrcode=="90I";
  replace ucrname="Tespass of Real Property"			if ucrcode=="90J";
  replace ucrname="All Other Offenses"				if ucrcode=="90Z";

end;

**;

  
/*

**************************************************;
*Table 1: Descriptive Stats on Inservice Days; 
**************************************************;

  use ${dcrime}\school_offenders.dta ;
  tsset cmy date;
  
 *Define inservice and break variables; 
  
  inservice; 

 *Create needed variables;
 
  gen fall=month>=8&month<=11;
  gen winter=month==12|month==1|month==2;
  gen spring=month>=3&month<=6;
  for num 1/12: gen mnX=month==X;
  gen dow=dow(date);
  gen dd_mon=dow==1;

  gen inservice1=inservice;
  replace inservice1=0.5 if inservice==1&half==1;

  for num 1 7: 
	gen tmp=nosch==0 \
	egen tmp2=sum(tmp), by(city year) \
	egen tmp3=sum(inserviceX), by(city year) \
	gen tmp4=(tmp3/tmp2)*180 \
	egen tag=tag(city year) \
	sort city year \ 
	list city year tmp2 tmp3 if tag==1 \
	table city if tag==1, c(mean tmp4 median tmp4 p10 tmp4 p90 tmp4) row \
	table city if inserviceX!=0, c(mean dd_mon mean dd_tue mean dd_wed mean dd_thu mean dd_fri) row \
	table city if inserviceX!=0, c(mean mn8 mean mn9 mean mn10 mean mn11 mean mn12) row \
	table city if inserviceX!=0, c(mean mn1 mean mn2 mean mn3 mean mn4 mean mn5) row \
	table city if inserviceX!=0, c(mean fall mean winter mean spring) row \
	drop tmp* tag ;
	
  drop dd_mon mn* fall winter spring;

 clear;
 

  
*I need to add in some code that creates the alternative inservice variables somewhere;

gen fall=month>=8&month<=11;
gen winter=month==12|month==1|month==2;
gen spring=month>=3&month<=6;
for num 1/12: gen mnX=month==X;
gen dd_mon=dow==1;

replace inservice1=0.5 if inservice1==1&half==1;

for num 1 4/7: 
	gen tmp=nosch==0 \
	egen tmp2=sum(tmp), by(city year) \
	egen tmp3=sum(inserviceX), by(city year) \
	gen tmp4=(tmp3/tmp2)*180 \
	egen tag=tag(city year) \
	sort city year \ 
	list city year tmp2 tmp3 if tag==1 \
	table city if tag==1, c(mean tmp4 median tmp4 p10 tmp4 p90 tmp4) row \
	table city if inserviceX!=0, c(mean dd_mon mean dd_tue mean dd_wed mean dd_thu mean dd_fri) row \
	table city if inserviceX!=0, c(mean mn8 mean mn9 mean mn10 mean mn11 mean mn12) row \
	table city if inserviceX!=0, c(mean mn1 mean mn2 mean mn3 mean mn4 mean mn5) row \
	table city if inserviceX!=0, c(mean fall mean winter mean spring) row \
	drop tmp* tag ;
	
drop dd_mon mn* fall winter spring;

*********************************************************;
*TABLE 2: Summary Stats for Jurisdictions vs the Nation crime rates;
*********************************************************;

use ${ducr}\da_ucr99.dta;

*This adds all of the total monthly crimes to get a yearly number;

 egen yrcrime=rsum(v95 v213 v331 v449 v567 v685 v803 v921 v1039 v1157
   v1275 v1393);

*This adds it for all jurisdictions;

 egen totcrime=sum(yrcrime);

*I divide total crimes by the 2000 population;

 gen crimert=totcrime/281421906;

 display "national crime rate";
 sum crimert;

*I now keep my sample cities;

 keep if
    v3=="ID01002" | v3=="UT00603" |
    v3=="UT00301" | v3=="ID01402" |
    v3=="ID04202" | v3=="UT01805" |
    v3=="UT01825" | v3=="SC02302" |
    v3=="CO00105" | v3=="IA00703" |
    v3=="CO00101" | v3=="CO02101" |
    v3=="CO03004" | v3=="ID00101" |
    v3=="IA05701" | v3=="IA07703" |
    v3=="IA08202" | v3=="MA00718" |
    v3=="MA01460" | v3=="OH05702" |
    v3=="OH07701" | v3=="OHCIP00" |
    v3=="SC04001" | v3=="TX22701" |
    v3=="UT02506" | v3=="VA11600" |
    v3=="IA05202" | v3=="ND05102" |
    v3=="ND00902";

 gen str9 ori=v3+"00";

 keep ori yrcrime;
 gen year=1999;

*I merge with population information;

 mmerge ori year using "${dnibrs}\pop9599.dta", type(n:1) unmatched(master) ukeep(ori year pop);

*I add total population and crimes and calculate the crime rate.;

collapse (sum) yrcrime pop;
gen samprt=yrcrime/pop;
l;
clear;

*********************************************************;
*TABLE 3: Summary Stats on Crime & School Session ;
*********************************************************;

  use ${dcrime}\school_offenders.dta ;
  
*Define inservice and break variables;
  inservice;

*Generate area of country dummy variables.;

    gen east=city=="Springfield, MA" | city=="Worcester, MA";
    gen midwest=city=="Cedar Rapids, IA" | city=="Des Moines, IA" |
     city=="Davenport, IA" | city=="Dayton, OH" | city=="Akron, OH" | city=="Cincinnati, OH" |
     city=="Waterloo, IA" | city=="Minot, ND" | city=="Iowa City, IA" | city=="Fargo, ND";
    gen mountain=city=="Aurora, CO" | city=="Colorado Springs, CO" |
     city=="Lakewood, CO" | city=="Boise, ID"  | city=="Provo, UT" | city=="Idaho Fall, ID" |
     city=="Twin Falls, ID" | city=="West Valley, UT" | city=="Idaho Falls, ID" |
     city=="Layton, UT" | city=="Logan, UT" | city=="Nampa, ID" | city=="Sandy, UT";
    gen south=city=="Columbia, SC" | city=="Newport News, VA" |
     city=="Greenville, SC" | city=="Westminster, CO" | city=="Austin, TX";

*Average values during a day;

  sum j_crimea j_viol j_prop j_otha j_groupb a_crimea a_viol a_prop a_otha a_groupb, detail;
  sum pop summer holiday break inservice mountain midwest east south;

clear;

********************************************;
*** OFFENDER STATS FOR TABLES 4-6 ***;
********************************************;

*Use offender files to create base data (from offenders_schol.do); 
 baseoff;
 keep if juv~=.;

*Merge on population information;
 mmerge ori year using "${dnibrs}\pop9599.dta", type(n:1) unmatched(master) ukeep(ori year pop);
 drop _merge;

*Merge on Calendar Information;
 calendar;

*** Create Offender Level and Other Variables ***;

format date %d;

gen byte black=race=="B" if race~="U";
gen byte white=race=="W" if race~="U";
gen byte other=1-black-white;

gen byte male=gender=="M" if gender~="U";
gen byte female=1-male;

gen byte a11=iage<=11;
gen byte a12_14=iage>=12 & iage<=14;
gen byte a15_17=iage>=15 & iage<=17;


*** Create Venue Variables ***;

 gen str20 venue_nm="School" if venue==22;
 replace venue_nm="Store/Restaurant" if venue==2 | venue==7 | venue==8
  | venue==9 | venue==12 | venue==17 | venue==21 | venue==23 | venue==24;
 replace venue_nm="Other Public Place" if venue==1 | venue==3 | venue==4
  | venue==5 | venue==6 | venue==10 | venue==11 | venue==13 | venue==14
  | venue==16 | venue==18;
 replace venue_nm="Residence" if venue==20;
 replace venue_nm="Other" if venue==15 | venue==19 | venue==25; 
 

*******************************************;
*TABLE 4: Offender summary statistics;
*******************************************;

sum iage a11 a12_14 a15_17 pop black white other male female if j_viol==1;
sum iage a11 a12_14 a15_17 pop black white other male female if j_prop==1;
sum iage a11 a12_14 a15_17 pop black white other male female if j_otha==1;


*******************************************;
*TABLE 5: What crimes do juveniles commit;
*******************************************;

 tab ucrname if juv==1 & groupb==0;
 tab ucrname if juv==1;

**************************************************;
*TABLE 6: Where do juveniles commit crime? ;
**************************************************;

sort nosch;

*Assault;
by nosch: tab venue_nm if (ucrcode=="13A" | ucrcode=="13B") & juv==1;

*Theft;
by nosch: tab venue_nm if (ucrcode=="23A" | ucrcode=="23B" | ucrcode=="23C" | ucrcode=="23D"
   | ucrcode=="23E" | ucrcode=="23F" | ucrcode=="23G" | ucrcode=="23H" | ucrcode=="240") & juv==1;

*Vandalism;
by nosch: tab venue_nm if ucrcode=="290" & juv==1;

*Drug Violations;
by nosch: tab venue_nm if ucrcode=="35A" & juv==1;

clear;

********************************************;
*TABLE 4: Summary Statistics on Victims ; 
********************************************;

*Create base victim files using previously created victim data (in victim_school.do); 

 use ${dcrime}\sch_vic95.dta;
 for num 96/99: append using "${dcrime}\sch_vicX.dta";
 
 egen tmp=nvals(year), by(ori incnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;

    gen str20 city="";
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

*For these tables we only need victims of juvenile violent crime;
 
 keep if viol==1 & juvoff==1;

*Create date variable;
  gen date = mdy(month, day, year);
  format date %d;

*Merge on Calendar Information (to match sample in the analysis);
 
 calendar;

*Generate some victim level demographic variables.;

 gen byte black=race=="B" if race~="U";
 gen byte white=race=="W" if race~="U";
 gen byte other=1-black-white;
 
 gen byte male=gender=="M" if gender~="U";
 gen byte female=1-male;
 
 gen age=real(vage);
 replace age=0 if vage=="NN" | vage=="NB" | vage=="BB";

 gen byte a11=age<=11 & age~=.;
 gen byte a12_14=age>=12 & age<=14 if age~=.;
 gen byte a15_17=age>=15 & age<=17 if age~=.;
 gen byte a18_24=age>=18 & age<=24 if age~=.;
 gen byte a25=age>=25 if age~=.;

*******************************************;
*Table 4 cont.  Victim Summary Statistics;
*******************************************;

sum age a11 a12_14 a15_17 a18_24 a25 black white other male female;
count if viol==1;



	* JIM - MAIN RESULTS START HERE *;
	
********************;
*** MAIN RESULTS ***;
********************;


***Data Prep***;

  use ${dcrime}\school_offenders.dta ;
  tsset cmy date;
  inservice; **This appropriately defines the inservice and break variables;


**************************************************;
*Table 7.  The mean number of crimes on school and non-school days.
**************************************************;

*Note: half days are considered school days in this specification;

  replace nosch=summer==1|inservice7==1|i_break7==1|break7==1|holiday==1|dd_sat==1|dd_sun==1;
  for var j_crimea j_viol j_prop j_otha j_groupb: gen X_rt=(X/pop)*100000;
  gen yessch=1-nosch;

**The following regressions simply compute averages.  I use the regression framework
**to allow clustered standard errors.;

  for any nosch yessch inservice7 i_break7 break7 summer holiday:
     regress j_crimea_rt if X==1 & dd_sun==0 & dd_sat==0, cluster(c) \
     regress j_viol_rt if X==1 & dd_sun==0 & dd_sat==0, cluster(c) \
     regress j_prop_rt if X==1 & dd_sun==0 & dd_sat==0, cluster(c) \
     regress j_otha_rt if X==1 & dd_sun==0 & dd_sat==0, cluster(c) \
     regress j_groupb_rt if X==1 & dd_sun==0 & dd_sat==0, cluster(c) ;


***************************************************;
*Table 8.  The effect of school term on the number of juvenile offenders.;
***************************************************;
  tsset cmy date;

  for any crimea viol prop otha groupb: xtnbreg j_X inservice7 i_break7 break7 summer holiday
   half dd*, fe i(cmy) ;

***************************************************;
*I now control for the number of adult crimes--we'll place this in a robustness check.;
***************************************************;

  for any crimea viol prop otha groupb: xtnbreg j_X a_X inservice7 i_break7 break7 summer
   half holiday dd*, fe i(cmy) ;

***************************************************;
*Table 9.  The effect of school term on specific juvenile offenses.;
***************************************************;

  for any burg veht shpl vand drug aslt aggaslt rob dscn loit serious: xtnbreg j_X
     inservice7 i_break7 break7 summer holiday half dd*, fe i(cmy) ;

***************************************************;
*Table 10.  The effect of school term on adult crime.;
***************************************************;

  for any crimea viol prop otha groupb: xtnbreg a_X  inservice7 i_break7 break7 summer
    holiday half dd*, fe i(cmy) ;

***************************************************;
*I now control for the number of juvenile crimes ;
***************************************************;

  for any crimea viol prop otha groupb: xtnbreg a_X j_X inservice7 i_break7 break7 summer
    holiday half dd*, fe i(cmy) ;


clear;



********************;
*** DISPLACEMENT ***;
********************;
  use ${dcrime}\school_offenders.dta ;
  tsset cmy date;
  inservice; **This appropriately defines the inservice and break variables;

 tsset c date;

***************************************************;
*I first create lagged inservice and break days.
***************************************************;

 gen sum_pr1=f.summer==1;
 gen sum_pr2=f.sum_pr1==1;
 gen sum_pr3=f.sum_pr2==1;
 gen sum_po1=l.summer==1;
 gen sum_po2=l.sum_po1==1;
 gen sum_po3=l.sum_po2==1;

 gen ins_pr1=f.inservice7==1;
 gen ins_pr2=f.ins_pr1==1;
 gen ins_pr3=f.ins_pr2==1;
 gen ins_po1=l.inservice7==1;
 gen ins_po2=l.ins_po1==1;
 gen ins_po3=l.ins_po2==1;

 gen brk_pr1=(f.break7==1 | f.i_break7==1 | f.holiday==1);
 gen brk_pr2=f.brk_pr1==1;
 gen brk_pr3=f.brk_pr2==1;
 gen brk_po1=(l.break7==1 | l.i_break7==1 | l.holiday==1);
 gen brk_po2=l.brk_po1==1;
 gen brk_po3=l.brk_po2==1;


***************************************************;
*Looking at lagged and lead values using the same negative binomial strategy.;
***************************************************;

  tsset cmy date;

  for any viol prop: 
  	xtnbreg j_X inservice7 ins_* i_break7 break7 holiday brk_* summer sum_* half dd*, fe i(cmy)\
     	test ins_pr1+ins_pr2+ins_pr3+ins_po1+ins_po2+ins_po3+inservice7=0;

  for any viol prop: 
  	xtnbreg j_X inservice7 ins_* i_break7 break7 holiday brk_* summer sum_* half dd*,
        fe i(cmy) ;


**********************************************************;
*Now I construct something linear by examining the rates using OLS.
**********************************************************;
  
  for var j_crimea j_viol j_prop j_otha j_groupb: gen X_rt=(X/pop)*100000;

  for any j_viol j_prop: 
    	areg X_rt inservice7 i_break7 break7 holiday summer half dd*, absorb(cmy) robust \
  	areg X_rt inservice7 ins_* i_break7 break7 holiday brk_* summer sum_* half dd*, absorb(cmy) robust\
     	test ins_pr1+ins_pr2+ins_pr3+ins_po1+ins_po2+ins_po3+inservice7=0;

  drop brk_*;
  drop ins_*;
  drop sum_*;
  

/***************************************************
*IV strategy to look at displacement. 
*Weeks defined as starting on Tuesday--this centers the week around Friday.
*Month variables defined as every four weeks, because months and weeks do not match exactly.
***************************************************/

  gen num_day=1;
  replace date=date-12786;
  gen week=int(date/7);
  gen nmonth=int(week/4);

  **I want to make sure this variable is coded up right;
  replace nosch=inservice7==1 | i_break7==1 | break7==1 | holiday==1 | summer==1 | dd_sat==1 |
    dd_sun==1;

  collapse (sum) inservice7 i_break7 break7 holiday half summer nosch j_crimea* j_viol* j_prop*
    j_otha* j_groupb* num_day, by(city nmonth week);

  keep if num_day==7;
  egen c_nmonth=group(city nmonth);
  tsset c_nmonth week;

  for any j_viol j_prop: 
  	reg X_rt nosch \
  	areg X_rt nosch, absorb(c_nmonth) robust\
  	areg X_rt inservice7 i_break7 break7 holiday summer half , absorb(c_nmonth) robust\
    	areg nosch inservice7 i_break7 break7 holiday summer half if X!=., absorb(c_nmonth) robust\
	xtivreg X_rt (nosch=inservice7) i_break7 break7 holiday summer half, fe i(c_nmonth) ;


/****************************************************************************************
 Because the neg. bin. regressions are nonlinear, the coefficients are percentages.  This
 *is now of a week instead of a day.  Thus the estimates will be changed--even if there
 *is no displacemnt.  To overcome this, I will divide all of the day variables by 7.  Thus
 *the interpretation will be if I increase inservice by 100 percent, what percent will crime
 *increase in a week.  It should then be comparable.;
 ******************************************************************************************/

   for any inservice7 i_break7 break7 holiday summer nosch half: replace X=X/7; 
   for any j_viol j_prop:
        xtnbreg X nosch,  \
        xtnbreg X nosch, fe i(c_nmonth)  \
        xtnbreg X inservice7 i_break7 break7 holiday summer half , fe i(c_nmonth) ;

clear;

*/

***************************************************;
*Tables 12.  Look at effect of school attendance on victimization.;
***************************************************;
  
  clear;
  use ${dcrime}\school_victim.dta ;
  
 *** Create inservice and break variables ***;
 inservice;
 tsset cmy date;

 *** Specifications ****;
  for any juv_juv_p juv_juv_v juv_adlt_p juv_adlt_v juv_inst: xtnbreg X inservice7 i_break7
    break7 holiday summer half dd*, fe i(cmy) ;



STOP;


clear;
**********************************************;
*** ROBUSTNESS CHECKS (Table 11 - ?? Rows) ***;
**********************************************;

***************************************************;
* Rows 1-3: Baseline + Consider only crime that take place during/after school hours;
***************************************************;
 
 use "${dcrime}\school_offenders.dta";
 
 *** Create inservice and break variables ***;
 inservice;
 tsset cmy date;

 *** Row 1: Baseline;
 for any viol prop: xtnbreg j_X inservice7 i_break7 break7 summer holiday half dd*, fe i(cmy) ;

 *** Row 1b: Control for adult crime ;
 for any viol prop: xtnbreg j_X a_X inservice7 i_break7 break7 summer holiday half dd*, fe i(cmy) ;

 *** Row 2: During school hours ***;
 for var j_sh_prop j_sh_viol: xtnbreg X inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;

 *** Row 3: During non-school hours ***;
 for var j_oh_prop j_oh_viol: xtnbreg X inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;

 clear;
 
********************************************************************;
* Row 4: Use arrests as the dependent variable instead of offenses *; 
********************************************************************;

 use "${dcrime}\school_arrests.dta";
 
 *** Redefine inservice and break variables ***;
 inservice;

 *** Run Specifications ***;
 tsset cmy date;
 for var j_prop j_viol: xtnbreg X inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;

 clear;

******************************************************************************;
* Row 8: Assign early morning crimes (12 a.m. to 6 a.m.) to the previous day *;
******************************************************************************;

*** Use offender files to create base data (from offenders_schol.do) ***; 
baseoff;

*** Reallocate early morning crimes to the previous day ***;

  replace date=date-1 if ihour<=5;
  
  collapse (sum) j_*, by(city date);
  gen month=month(date);
  gen year=year(date);
  gen day=day(date);
  egen c=group(city);

/* Some small cities may have no crime reported on a given day.  The next lines ensure that these
   zero crime days are reported as zeros instead of missing values.  I then eliminate the months
   with missing data in the subsequent section. */

  tsset c date;
  tsfill;
  for var j_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: 
  	replace city=city[_n-X] if c==c[_n-X] & city=="" \
  	replace city=city[_n+X] if c==c[_n+X] & city=="";


 tsset c date;
 egen cmy=group(city month year);

*** Merge on Calendar Information ***;
 
  calendar;

*** Create Inservice and Break Variables ***;

  inservice; 
  tsset cmy date;

*** Run Specifications (early morning crimes assigned to previous day) ***;

 xtnbreg j_prop inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;
 xtnbreg j_viol inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;

clear;


*******************************************************;
* Row 9: Consider only crimes not performed in school *;
*******************************************************;

*** Use offender files to create base data (from offenders_schol.do) ***; 

  baseoff;

*** Modify Code - drop incidents outside of school ***;

  drop if venue==22;

  collapse (sum) j_*, by(city date);
  gen month=month(date);
  gen year=year(date);
  gen day=day(date);
  egen c=group(city);

/* Some small cities may have no crime reported on a given day.  The next lines ensure that these
   zero crime days are reported as zeros instead of missing values.  I then eliminate the months
   with missing data in the subsequent section. */

  tsset c date;
  tsfill;
  for var j_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: 
  	replace city=city[_n-X] if c==c[_n-X] & city=="" \
  	replace city=city[_n+X] if c==c[_n+X] & city=="";


 tsset c date;
 egen cmy=group(city month year);

*** Merge on Calendar Information ***;

  calendar;

*** Create Inservice and Break Variables ***;

  inservice; 
  tsset cmy date;

*** Run Specifications ***;

 xtnbreg j_prop inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;
 xtnbreg j_viol inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;

 clear;



****************************************************************************************;
* Row 5: Dependent variable is the number of incidents rather than number of offenders *; 
****************************************************************************************;

*** Use offender files to create base data (from offenders_schol.do) ***; 

  baseoff;

*** Collapse the data to create one obs per incident ***;
  
  drop j_prop j_viol;
  collapse (max) juv viol prop, by(city incnum date);

*** Collapse the data to create one obs per city and date ***;
  
  for any prop viol: gen j_X=juv*X;

  collapse (sum) j_*, by(city date);
  gen month=month(date);
  gen year=year(date);
  gen day=day(date);
  egen c=group(city);

/* Some small cities may have no crime reported on a given day.  The next lines ensure that these
   zero crime days are reported as zeros instead of missing values.  I then eliminate the months
   with missing data in the subsequent section. */

  tsset c date;
  tsfill;
  for var j_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: 
  	replace city=city[_n-X] if c==c[_n-X] & city=="" \
  	replace city=city[_n+X] if c==c[_n+X] & city=="";


 tsset c date;
 egen cmy=group(city month year);

*** Merge on Calendar Information ***;

  calendar;

*** Create Inservice and Break Variables ***;

  inservice; 
  tsset cmy date;

*** Run Specifications ***;
 sum j_prop j_viol;  
 *This line provides the average number of incidents involving at least one
 juvenile in our sample.  We use this to calculate the cost of increasing the school
 year by one day, which is discussed in the conclusion of our paper;
 

 xtnbreg j_prop inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;
 xtnbreg j_viol inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;

 clear;

/****************************************************************************************
 * Row 6: Dependent variable is the number of INCIDENTS involving ONLY 1 juvenile
 * Row 7: Dependent variable is the number of INCIDENTS involving MORE THAN 1 juvenile 
 *
 * The idea here is that we are looking for evidence that school plays a role in the 
 * coordination of crime, in which case we would expect to see a greater decrease in the 
 * prevalence of multiple offender incidents when school is not in session as compared to single
 * offender incidents.
 *****************************************************************************************/


*** Use offender files to create base data (from offenders_school.do) ***; 

  baseoff;

*** Collapse the data to create one obs per incident ***;
*** Record the number of offenders in each incident ***;
 
 drop j_prop j_viol;
 
 gen off_num=juv==1 | adlt==1;
 gen juv_num=juv;
 collapse (sum) juv_num off_num (max) juv adlt viol prop,  by(city incnum date);
 gen j1=juv_num==1;
 gen p1=off_num==1;
 gen j2=juv_num>1;
 gen p2=off_num>1;

*** Collapse the data to create one obs per city and date ***;

  for any prop viol: gen j_X_j1=juv*X*j1 \ gen j_X_j2=juv*X*j2 \ gen j_X_p1=juv*X*p1
    \ gen j_X_p2=juv*X*p2;

  collapse (sum) j_*, by(city date);
  gen month=month(date);
  gen year=year(date);
  gen day=day(date);
  egen c=group(city);

/* Some small cities may have no crime reported on a given day.  The next lines ensure that these
   zero crime days are reported as zeros instead of missing values.  I then eliminate the months
   with missing data in the subsequent section. */

  tsset c date;
  tsfill;
  for var j_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: 
  	replace city=city[_n-X] if c==c[_n-X] & city=="" \
  	replace city=city[_n+X] if c==c[_n+X] & city=="";


 tsset c date;
 egen cmy=group(city month year);

*** Merge on Calendar Information ***;

  calendar;

*** Create Inservice and Break Variables ***;

  inservice; 
  tsset cmy date;

*** Run Specifications ***;

 for any j1 j2 p1 p2:  
 	xtnbreg j_prop_X inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy)  \ 
 	xtnbreg j_viol_X inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;

clear;


/****************************************************************************************
 * Row 10+ : Use more liberal definition of inservice days 
 *****************************************************************************************/

  use ${dcrime}\school_offenders.dta ;

   **Set breaks and holidays to zero for half days;
   for var break holiday: replace X=0 if half==1;
   replace half=0 if half==.;
 
   **All inservice days;
   gen inservice6=inservice;
   gen break6=break;
   
   **Getting rid of half days;
   replace inservice6=0 if half==1;
   count if inservice6==1;
 
   **Create idiosyncratic and regular break.;
   gen tmpvar1=break6+holiday;
   egen tmpvar2=mean(tmpvar1), by(date);
   gen i_break6=break6;
   replace i_break6=0 if tmpvar2>.3;
   replace break6=break6-i_break6;
   drop tmpvar*;

   tsset cmy date;

   for var j_viol j_prop: xtnbreg X inservice6 i_break6 break6 holiday summer half dd*,
      fe i(cmy) ; 

   clear;


*****************************************************************;
*The next lines assign examine whether the "friday night effect" is in fact driven by
*evening property crime from the previous day.;
*****************************************************************;
**************************************************;
*These regressions examine the effect of school calendars on property crime from the previous day.
*It's trying to determine whether the apparent friday night effect is in fact driven by evening
*(post 9 p.m.) crimes.;
**************************************************;

********************************************************;
*I use the data I created with offenders_school.do.
********************************************************;

  baseoff;

*************************;
*I break up previous day crimes according to whether they occurred
*before or after 9 p.m.  This just shows that the friday night effect
*is in fact driven by stuff going on at night.;
*************************;

  replace date=date+1;
  gen nt=ihour>=21 & ihour~=.;
  gen dy=ihour<21 & ihour~=.;

  for any nt dy: gen j_prop_X=prop*juv*X;

  collapse (sum) j_*, by(city date);
  gen month=month(date);
  gen year=year(date);
  gen day=day(date);
  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var j_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";


 tsset c date;

*** Create other variables ***;

 egen cmy=group(city month year);

*** Merge on Calendar Information ***;

  calendar;

*** Create Inservice and Break Variables ***;

  inservice; 
  tsset cmy date;

*** Run Specifications ***;

 xtnbreg j_prop_dy inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;
 xtnbreg j_prop_nt inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;

clear;

****************************************************;
*Merge in weather data and control for (mean) temperature and precipitation.;
****************************************************;

  use ${dcrime}\school_offenders.dta ;
  inservice;
  sort city year month day;
  merge city year month day using ${dcrime}\final_small.dta ;
  tab _merge;
  keep if _merge==3;
  drop _merge;

 tsset cmy date;

 xtnbreg j_prop inservice7 Tmean Prcp i_break7 break7 holiday summer half dd*, fe i(cmy) ;
 xtnbreg j_viol inservice7 Tmean Prcp i_break7 break7 holiday summer half dd*, fe i(cmy) ;

 clear;

****************************************************;
* TABLE 13 - HETEROGENEITY OF RESULTS BY OFFENDER *;
****************************************************;

*****************************************************************;
*The next lines look at the effects by city population.;
*****************************************************************;

 use "${dcrime}\school_offenders.dta";
 egen maxpop=max(pop), by(city);
 inservice;

 tsset cmy date;
 xtnbreg j_prop inservice7 i_break7 break7 holiday summer half dd* if maxpop>120000, fe i(cmy) ;
 xtnbreg j_viol inservice7 i_break7 break7 holiday summer half dd* if maxpop>120000, fe i(cmy) ;
 xtnbreg j_prop inservice7 i_break7 break7 holiday summer half dd* if maxpop<=120000, fe i(cmy) ;
 xtnbreg j_viol inservice7 i_break7 break7 holiday summer half dd* if maxpop<=120000, fe i(cmy) ;

 clear;

*****************************************************************;
*The next lines look at crime by gender and race.;
*****************************************************************;
baseoff;

  
  gen male=gender=="M";
  gen female=gender=="F";
  gen black=race=="B";
  gen white=race=="W";

********************;
*I create violent and property crimes by gender and race.;
********************;

    for any viol prop: gen j_f_X=X*juv*female \ gen j_m_X=X*juv*male \ gen j_b_X=X*juv*black \
       gen j_w_X=X*juv*white;

  
  collapse (sum) j_*, by(city date);
  gen month=month(date);
  gen year=year(date);
  gen day=day(date);
  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var j_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";

*Create other variables;
 egen cmy=group(city month year);

******************************************************************************
*Merge on Calendar Information.
******************************************************************************;

calendar;
inservice;

tsset cmy date;

 for any m f b w:
    xtnbreg j_X_prop inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy)  \
    xtnbreg j_X_viol inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;
 
 clear;


*****************************************************************;
*The next lines look at crime by age.;
*****************************************************************;
baseoff;

  
*******************;
*I create the crime variables by age.
*******************;

    gen a14=iage<15;
    gen a17=iage>=15 & iage<=17;
    for any viol prop: gen j_14_X=X*juv*a14 \ gen j_17_X=X*juv*a17;

  
  collapse (sum) j_*, by(city date);
  gen month=month(date);
  gen year=year(date);
  gen day=day(date);
  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var j_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";

*Create other variables;
 egen cmy=group(city month year);

******************************************************************************
*Merge on Calendar Information.
******************************************************************************;

calendar;
inservice;

tsset cmy date;

 for any 14 17:
    xtnbreg j_X_prop inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy)  \
    xtnbreg j_X_viol inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;
 
 clear;



******************************************************************************
*Running different types of specifications to check the appropriateness of the
*xtnbreg method.
******************************************************************************;

  use ${dcrime}\school_offenders.dta ;
  inservice;
  for var j_prop j_viol a_prop a_viol j_agg: gen X_rt=(X/pop)*100000;
  tsset cmy date;
 for var j_prop j_viol: areg X_rt inservice7 i_break7 break7 holiday summer half dd*,
   robust absorb(cmy) \
   predict X_pred \
   gen X_neg=X_pred<0 \
   tab X_neg \
   areg X_rt inservice7 i_break7 break7 holiday summer half dd* [pweight=pop],
   robust absorb(cmy) \
   xtpois X inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) \
   regress X_rt \
   regress X_rt [pweight=pop];


******************************************************************************
*Check results to combine idiosyncratic breaks and inservice days.;
******************************************************************************;
   gen inservice8=inservice7+i_break7;
   for var j_prop j_viol a_prop a_viol j_aggaslt:
         xtnbreg X inservice8 break7 holiday summer half dd*, fe i(cmy)  \
         areg X_rt inservice8 break7 holiday summer half dd*, robust absorb(cmy)\
         areg X_rt inservice8 break7 holiday summer half dd* [pweight=pop],
           robust absorb(cmy) ;

clear;

******************************************************************************;
*Look at aggravated assaults by school hours.;
******************************************************************************;

baseoff;

gen agg=ucrcode=="13A";
gen j_agg=juv*agg;

capture drop schr othr;
gen schr=ihour>6 & ihour<=14;
gen othr=schr==0 & ihour~=.;

gen j_agg_schr=j_agg*schr;
gen j_agg_othr=j_agg*othr;

  collapse (sum) j_agg_schr j_agg_othr, by(city date);
  gen month=month(date);
  gen year=year(date);
  gen day=day(date);
  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var j_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";

*Create other variables;
 egen cmy=group(city month year);

******************************************************************************
*Merge on Calendar Information.
******************************************************************************;

calendar;
inservice;

tsset cmy date;

    xtnbreg j_agg_schr inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;
    xtnbreg j_agg_othr inservice7 i_break7 break7 holiday summer half dd*, fe i(cmy) ;
 
 clear;

***********************************************************************************;
*Now we look to see which age groups are most affected by juvenile crime on inservice
*days.;
***********************************************************************************;

  use ${dcrime}\sch_vic95;
  for num 96/99: append using "${dcrime}\sch_vicX";


*Rarely the information is recorded in multiple years.  The next lines take care of this.;

 egen tmp=nvals(year), by(ori incnum vicnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;

 gen tmpvar=real(vage);
 drop vage;
 rename tmpvar vage;

 gen a1820=vage>=18 & vage<=20;
 gen a2124=vage>=21 & vage<=24;
 gen a1824=vage>=18 & vage<=24;
 gen a2535=vage>=25 & vage<=35;
 gen a3699=vage>=36;

 for any a1820 a2124 a1824 a2535 a3699: gen j_viol_X=X==1 & juvoff==1 & viol==1\
    gen j_prop_X=X==1 & juvoff==1 & prop==1;

 collapse (sum) j_viol_* j_prop_*, by(ori year month day);
 gen date=mdy(month, day, year);

*** Label Cities ***;

    gen str20 city="";
    
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

    label variable city "city";

  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var j*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";


 egen cmy=group(city month year);

*Merge on population information;

 mmerge ori year using "${dnibrs}\pop9599.dta", type(n:1) unmatched(master) ukeep(ori year pop);
 sum pop, det;
 drop _merge;

 calendar;
 inservice;
 tsset cmy date;

 for var j_*: xtnbreg X inservice7 i_break7 break7 holiday summer dd*, fe i(cmy) ;
 clear;


***********************************************************************************;
*This part of the file will redo the figures in the paper.
***********************************************************************************;

baseoff;
keep city ori date year month day juv adlt prop viol ihour;
calendar;
keep if summer~=.;

*Tabbing the hour allows me to calculate the fraction of
*crimes that occurred in each hour.;


 tab ihour if juv==1 & viol==1;
 tab ihour if adlt==1 & viol==1;

 tab ihour if juv==1 & prop==1;
 tab ihour if adlt==1 & prop==1;

 tab ihour if juv==1 & viol==1 & nosch==1;
 tab ihour if juv==1 & viol==1 & nosch==0;

 tab ihour if juv==1 & prop==1 & nosch==1;
 tab ihour if juv==1 & prop==1 & nosch==0;

 clear; 


**********************************************************************************;
*I will now examine a some additional specifications that do not appear in tables
*but are included either in the text or the letter to the editor.
**********************************************************************************;


  use ${dcrime}\school_offenders.dta ;
  inservice;
  tsset cmy date;

**We look to see if the results are the same when we exclude weekends.;
  for var j_viol j_prop: xtnbreg X inservice7 i_break7 break7 holiday summer dd*
     if dd_sun==0 & dd_sat==0, fe i(cmy);

**We now exclude weekends and summer vacation.;
  for var j_viol j_prop: xtnbreg X inservice7 i_break7 break7 holiday dd*
     if dd_sun==0 & dd_sat==0 & summer==0, fe i(cmy);

**We now exclude Charleston, SC which had a bit of confusion over the jurisdiction.;
  for var j_viol j_prop: xtnbreg X inservice7 i_break7 break7 holiday dd*
     if city~="Columbia, SC", fe i(cmy);

clear;


  */
************************************************************************************;
*This next file calculates the fraction of offenders with missing age by offense
*category.
************************************************************************************;


*Merge together annual files with one obs per offender x incident;

 use ${dcrime}\groupa95.dta;
 for num 96/99: append using "${dcrime}\groupaX.dta";
 
*This drops duplicate observations (if an incident took place in one year, but the resulting arrest
 took place in another year, there will be observations in both years, but only the latest year will
 contain all relevant information.  Hence, only keep max year obs;
 
 egen tmp=nvals(year), by(ori incnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;

*Create indicators for violent and property crime;

 gen byte viol=ucrcode=="13A" | ucrcode=="13B" | ucrcode=="13C" | ucrcode=="09A" | ucrcode=="09B"
    | ucrcode=="09C" | ucrcode=="100" | ucrcode=="11A" | ucrcode=="11B" | ucrcode=="11C" 
    | ucrcode=="11D" | ucrcode=="36A" | ucrcode=="36B";

 gen byte prop=ucrcode=="510" | ucrcode=="220" | ucrcode=="250" | ucrcode=="290" | ucrcode=="210" 
    | ucrcode=="270" | ucrcode=="26A" | ucrcode=="26B" | ucrcode=="26C"
    | ucrcode=="26D" | ucrcode=="26E" | ucrcode=="23A" | ucrcode=="23B" | ucrcode=="23C"
    | ucrcode=="23D" | ucrcode=="23E" | ucrcode=="23F" | ucrcode=="23G" | ucrcode=="23H"
    | ucrcode=="240" | ucrcode=="120" | ucrcode=="280";




*Create date variable;

 gen date = mdy(month, day, year);
 format date %d;

*Label cities;

    gen str20 city="";
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

 keep ori city date year month day iage viol prop;

calendar;
keep if summer~=.;

gen missage=iage==.;
sum missage if viol==1;
sum missage if prop==1;
sum missage;

clear;


***************************************************************************
*This part of the file will examine what fraction of incidents end with offender,
*arrest, and victim information.
***************************************************************************

********************************************;
*DATA PREP.
********************************************;

program define data_count;

***************************;
*I will get the number of incidents from the 
*administrative file.;
***************************;

  use V1003 V1004 V1005 V1006 if 
    V1003=="ID0100200" | V1003=="UT0060300" |
    V1003=="UT0030100" | V1003=="ID0140200" |
    V1003=="ID0420200" | V1003=="UT0180500" |
    V1003=="UT0182500" | V1003=="SC0230200" |
    V1003=="CO0010500" | V1003=="IA0070300" |
    V1003=="CO0010100" | V1003=="CO0210100" |
    V1003=="CO0300400" | V1003=="ID0010100" |
    V1003=="IA0570100" | V1003=="IA0770300" |
    V1003=="IA0820200" | V1003=="MA0071800" |
    V1003=="MA0146000" | V1003=="OH0570200" |
    V1003=="OH0770100" | V1003=="OHCIP0000" |
    V1003=="SC0400100" | V1003=="TX2270100" |
    V1003=="UT0250600" | V1003=="VA1160000" |
    V1003=="IA0520200" | V1003=="ND0510200" |
    V1003=="ND0090200"
    using ${dnibrs}\nibrs`1'_adm.dta;
  
   rename V1003 ori;
   rename V1004 incnum;
   rename V1005 incdate;
   rename V1006 repdate;
  
********************************************************************************;
*About 10-20% of incidents have dates that correspond to reporting and not occurence;
*We will only examine incidents that occured on the incident date--not incidents
*that were reported on the incident date so we drop the other observations;
********************************************************************************;
   
  tab repdate, missing;
  keep if repdate=="";
  drop repdate;
  drop if ori=="";
  
  
  *I only want one record per incident;
  *I will merge in the offender, arrest and victim data such that we only keep this info for obs that are
   included in the incident file;
  *Therefore, all obs should have increp==1, which will be a good test of the program;
  
  sort ori incnum;
  gen increp=1;
 
  save tmp, replace;
  clear;

***********************************************************;
*I will now read in offender data.
***********************************************************;
  
  
  use V5003 V5004 V5007 if 
    V5003=="ID0100200" | V5003=="UT0060300" |
    V5003=="UT0030100" | V5003=="ID0140200" |
    V5003=="ID0420200" | V5003=="UT0180500" |
    V5003=="UT0182500" | V5003=="SC0230200" |
    V5003=="CO0010500" | V5003=="IA0070300" |
    V5003=="CO0010100" | V5003=="CO0210100" |
    V5003=="CO0300400" | V5003=="ID0010100" |
    V5003=="IA0570100" | V5003=="IA0770300" |
    V5003=="IA0820200" | V5003=="MA0071800" |
    V5003=="MA0146000" | V5003=="OH0570200" |
    V5003=="OH0770100" | V5003=="OHCIP0000" |
    V5003=="SC0400100" | V5003=="TX2270100" |
    V5003=="UT0250600" | V5003=="VA1160000" |
    V5003=="IA0520200" | V5003=="ND0510200" |
    V5003=="ND0090200"
  using ${dnibrs}\nibrs`1'_off.dta;
  
  rename V5003 ori;
  rename V5004 incnum;
  rename V5007 age;
  
  *The next lines let me know if the offender file contains age information
  *on at least one offender associated with the incident.;

  gen offinfo=1;
  tab offinfo, m;

  collapse (max) offinfo mxoffage=age (min) mnoffage=age, by(ori incnum);
  count;
  
  display "** Merge original incident data (tmp) to the existing offender file **";
  
  *If indeed there is some offender info for all incidents, each file should have the exact same number of observations, 
   with the exception that the offender file will have info on incidents where the report date is used and we have thus
   excluded;
  *we want to keep if the obs were in the using data set - unmatched(using);
  
   mmerge ori incnum using tmp, type(1:1); 
   keep if _merge==3|_merge==2;  		*this keeps if obs was in both or obs was only in using ;
   

  drop _merge;
  sort ori incnum;
  save tmp, replace;
  clear;
  
  
***********************************************************;
*I will now read in arrest data.
***********************************************************;
  
  
  use V6003 V6004 V6014 if 
    V6003=="ID0100200" | V6003=="UT0060300" |
    V6003=="UT0030100" | V6003=="ID0140200" |
    V6003=="ID0420200" | V6003=="UT0180500" |
    V6003=="UT0182500" | V6003=="SC0230200" |
    V6003=="CO0010500" | V6003=="IA0070300" |
    V6003=="CO0010100" | V6003=="CO0210100" |
    V6003=="CO0300400" | V6003=="ID0010100" |
    V6003=="IA0570100" | V6003=="IA0770300" |
    V6003=="IA0820200" | V6003=="MA0071800" |
    V6003=="MA0146000" | V6003=="OH0570200" |
    V6003=="OH0770100" | V6003=="OHCIP0000" |
    V6003=="SC0400100" | V6003=="TX2270100" |
    V6003=="UT0250600" | V6003=="VA1160000" |
    V6003=="IA0520200" | V6003=="ND0510200" |
    V6003=="ND0090200"
  using ${dnibrs}\nibrs`1'_arr.dta;
  
  rename V6003 ori;
  rename V6004 incnum;
  rename V6014 age;
  
  *Again I generate a record for incidents in which at least one
  *arrestee has age information.;
  
  gen arrinfo=1;
  tab arrinfo, m;

  collapse (max) arrinfo mxarrage=age (min) mnarrage=age, by(ori incnum);
  count;
  
  display "** merge original incident/offender data (tmp) with the current arrest file **";
  
  *there may well be no arrest associated with the incident, so we want to keep obs that are only in the using data set
   as well as obs in both data sets;
  
  mmerge ori incnum using tmp, type(1:1) ;
  keep if _merge==3|_merge==2;  		*this keeps if obs was in both or obs was only in using ;
 
  drop _merge;
  sort ori incnum;
  
***********************************************************;
*Every offense necessarily has a victim so I won't look
*at victim data.
***********************************************************;
 
 display "** delete tmp file and save base year file **";

  ! del tmp.dta ;
  save data_count`1', replace;
  clear;

end;


data_count 95;
data_count 96;
data_count 97;
data_count 98;
data_count 99;



**********************************;
*** Merge together 95-99 files ***;
**********************************;


use data_count95;
  for num 96/99: append using data_countX;

 gen year=real(substr(incdate,1,4));
   label variable year "year of incident";
 gen month=real(substr(incdate,5,2));
   label variable month "month of incident";
 gen day=real(substr(incdate,7,2));
   label variable day "day of incident";

 egen tmp=nvals(year), by(ori incnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;
replace arrinfo=0 if arrinfo==.;


*** Label Cities ****;

    gen str20 city="";
    
    
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

    label variable city "city";

keep incnum mn* mx* offinfo arrinfo city year month day;


*The following approximates our sample though it may not be exact.  It should be 
*very close, however, and is probably appropriate for this small note.;

  drop if city=="Akron, OH" & year<1999;
  drop if city=="Anderson, SC" & year==1995 & (month==11|month==12);
  drop if city=="Aurora, CO" & year<1997;
  drop if city=="Austin, TX" & year<1998;
  drop if city=="Beaufort, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Boise, ID" & year<1995 ;
  drop if city=="Cedar Rapids, IA" & year<1999;
  drop if city=="Charleston, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Cincinnati, OH" & year<1998;
  drop if city=="Clarksville, TN" & year<1998;
  drop if city=="Colorado Springs, CO" & year<1997;
  drop if city=="Columbia, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Council Bluffs, IA" & year<1998;
  drop if city=="Davenport, IA" & year==1996 & month==7;
  drop if city=="Dayton, OH" & year<1998;
  drop if city=="Des Moines, IA" & year<1995;
  drop if city=="Florence, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Greenville, SC" & year<1995;
  drop if city=="Jackson, MI" & year<1997;
  drop if city=="Lakewood, CO" & year<1997;
  drop if city=="Myrtle Beach, SC" & year==1995 & (month==11|month==12);
  drop if city=="Newport News, VA" & (year<1998 | (year==1998 & month<7));
  drop if city=="Orangeburg, SC" & year==1995 & (month==11|month==12);
  drop if city=="Petersburg, VA" & ((year==1995 & month<10)|(year==1999 & month==6));
  drop if city=="Provo, UT" & year<1995;
  drop if city=="Sandy, UT" & year<1995;
  drop if city=="Sioux City, IA" & year<1995;
  drop if city=="Southfield, MI" & (year<1996 | (year==1996 & month<5)); 
  drop if city=="Spartanburg, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Springfield, MA" & (year<1996 | (year==1996 & month<6));
  drop if city=="Sterling Heights, MI" & year==1995 & month<3;
  drop if city=="Waterloo, IA" & ((year==1996 & month<8) | year<1996);
  drop if city=="West Valley, UT" & ((year==1998 & month<8) | year<1998);
  drop if city=="Westminster, CO" & ((year==1999 & month==1) | (year==1998 & month==12)
     | (year==1997 & month>3) | year<1997);
  drop if city=="Worcester, MA" & year<1995;
  drop if city=="Idaho Falls, ID" & year<1995;
  drop if city=="Nampa, ID" & year<1995;
  drop if city=="Twin Falls, ID" & year<1995;
  drop if city=="Layton, UT" & ((year==1999 & month>=3 & month<=5) | (year==1998 & month>=7)
     | (year==1996 & month==9) | (year==1995 & month>=7 & month<=8) | (year==1995 & month<9)
     | year<1995);
  drop if city=="Logan, UT" & ((year==1999 & month==12) | (year==1998 & month>=11) | year<1995);
  drop if city=="Nampa, ID" & (year==1995 & (month==11 | month==12));
  drop if city=="Iowa City, IA" & (year<1996 | (year==1996 & month<8)); **Calendar data missing 1995/1996;
  drop if city=="Minot, ND" & (year==1995 & (month==11 | month==12));
  drop if city=="Fargo, ND" & year<1995;


compress;

***********************************************;
*** Run basic stats on full analysis sample ***;
***********************************************;

replace arrinfo=0 if arrinfo==.;

gen doffage=mxoffage!=.;
gen darrage=mxarrage!=. if arrinfo==1;

gen offagec=1 		if mnoffage<18&mnoffage!=.;
replace offagec=2	if mnoffage>=18&mnoffage<24&mnoffage!=.;
replace offagec=3	if mnoffage>=24&mnoffage<35&mnoffage!=.;
replace offagec=4	if mnoffage>=35&mnoffage!=.;
 *missing values here signify that offender age was unknown;

gen arragec=0		if arrinfo==0;
replace arragec=1 	if arrinfo==1&mnarrage<18&mnarrage!=.;
replace arragec=2	if arrinfo==1&mnarrage>=18&mnarrage<24&mnarrage!=.;
replace arragec=3	if arrinfo==1&mnarrage>=24&mnarrage<35&mnarrage!=.;
replace arragec=4	if arrinfo==1&mnarrage>=35&mnarrage!=.;
 *missing values here signify that there was an arrest, but that arrestee age was unknown;
 *zero signifies that no arrest was made;
 
 
display "** what percent of incidents have offender and arrest info **";
   tab offinfo arrinfo, m;

display "** for what percent of incidents do we know offender age **";
  tab doffage, m;
  
display "** for what percent of incidents/arrests do we know arrestee age **";
  tab darrage, m;

display "** 2x2 matrix **";
  tab doffage darrage, row col cell m;

display "** correlation btw offender age and arrest age **";
  tab offagec arragec if doffage==1 & arrinfo==1 & darrage==1, m;

corr mnoffage mnarrage;
corr mxoffage mxarrage;

clear;


********************************************************************************************;
*I will now examine the effect of inservice on the fraction of offenders that have missing
*age variables as a function of the inservice days.
********************************************************************************************;

*Merge together annual files with one obs per offender x incident;

 use ${dcrime}\groupa95.dta;
 for num 96/99: append using "${dcrime}\groupaX.dta";
 
*This drops duplicate observations (if an incident took place in one year, but the resulting arrest
 took place in another year, there will be observations in both years, but only the latest year will
 contain all relevant information.  Hence, only keep max year obs;
 
 egen tmp=nvals(year), by(ori incnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;

*Create indicators for violent and property crime;

 gen byte viol=ucrcode=="13A" | ucrcode=="13B" | ucrcode=="13C" | ucrcode=="09A" | ucrcode=="09B"
    | ucrcode=="09C" | ucrcode=="100" | ucrcode=="11A" | ucrcode=="11B" | ucrcode=="11C" 
    | ucrcode=="11D" | ucrcode=="36A" | ucrcode=="36B";

 gen byte prop=ucrcode=="510" | ucrcode=="220" | ucrcode=="250" | ucrcode=="290" | ucrcode=="210" 
    | ucrcode=="270" | ucrcode=="26A" | ucrcode=="26B" | ucrcode=="26C"
    | ucrcode=="26D" | ucrcode=="26E" | ucrcode=="23A" | ucrcode=="23B" | ucrcode=="23C"
    | ucrcode=="23D" | ucrcode=="23E" | ucrcode=="23F" | ucrcode=="23G" | ucrcode=="23H"
    | ucrcode=="240" | ucrcode=="120" | ucrcode=="280";


 gen byte crimea=1;

  gen byte otha=crimea-viol-prop;

  gen age_missing=iage==.;

  gen viol_missing=viol*age_missing;
  gen prop_missing=prop*age_missing;
  gen crimea_missing=crimea*age_missing;
  gen otha_missing=otha*age_missing;


  collapse (sum) viol* prop* crimea* otha* , by(ori year month day) ;

 gen date = mdy(month, day, year);
 format date %d;

*Label cities;

    gen str20 city="";
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

  format date %d;
  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var viol* prop* crimea* otha*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";

  egen cmy=group(city month year);
  calendar;

*I will keep only those observations with offender data;
 keep if viol~=.;
 
 gen frac_viol_missing=viol_missing/viol;
 gen frac_prop_missing=prop_missing/prop;
 gen frac_crimea_missing=crimea_missing/crimea;
 gen frac_otha_missing=otha_missing/otha;
  
 inservice;

tsset cmy date;
for var frac_*: xtreg X inservice7 i_break7 break7 holiday summer dd*, fe i(cmy);

clear;




program define prop_cost;

*****************************************************************************;
*What is the average cost of property offenses committed by juveniles?
*****************************************************************************;

*****************************************************************************;
*I first read in administrative information so I can find out the incident
*date and other information.;
*****************************************************************************;


use V1003 V1004 V1005 V1006 if 
    V1003=="ID0100200" | V1003=="UT0060300" |
    V1003=="UT0030100" | V1003=="ID0140200" |
    V1003=="ID0420200" | V1003=="UT0180500" |
    V1003=="UT0182500" | V1003=="SC0230200" |
    V1003=="CO0010500" | V1003=="IA0070300" |
    V1003=="CO0010100" | V1003=="CO0210100" |
    V1003=="CO0300400" | V1003=="ID0010100" |
    V1003=="IA0570100" | V1003=="IA0770300" |
    V1003=="IA0820200" | V1003=="MA0071800" |
    V1003=="MA0146000" | V1003=="OH0570200" |
    V1003=="OH0770100" | V1003=="OHCIP0000" |
    V1003=="SC0400100" | V1003=="TX2270100" |
    V1003=="UT0250600" | V1003=="VA1160000" |
    V1003=="IA0520200" | V1003=="ND0510200" |
    V1003=="ND0090200"  using ${dnibrs}\nibrs`1'_adm.dta;


 rename V1003 ori;
 rename V1004 incnum;
 rename V1005 incdate;
 rename V1006 repdate;
 
 keep if repdate=="";
 drop if ori=="";
 keep if incdate~="";
  
*******************************************************************************;
*Merge on property data.;
*******************************************************************************;

mmerge ori incnum using ${dnibrs}\nibrs`1'_prp.dta, type(n:n) umatch(V3003 V3004) 
   unmatched(master) ukeep (V3008 V3007)
   urename (V3008 prop_val \ V3007 prop_dsc);

drop if prop_val==. | prop_val==1;
*1 is a missing value in this case;

drop if prop_dsc==10 | prop_dsc==11;
*The previous line drops drug values.;

drop if incdate=="";

*I want total damage amounts for each incident;

collapse (sum) prop_val, by(ori incnum incdate);


********************************************************************************;
*I will now merge in offense data to be able to obtain ucrcodes.
********************************************************************************; 

 mmerge ori incnum using "${dnibrs}\nibrs`1'_inc.dta", type(1:n) umatch(V2003 V2004)
 unmatched(master) ukeep(V2006) urename (V2006 ucrcode);
 gen byte prop=ucrcode=="510" | ucrcode=="220" | ucrcode=="250" | ucrcode=="290" | ucrcode=="210" 
    | ucrcode=="270" | ucrcode=="26A" | ucrcode=="26B" | ucrcode=="26C"
    | ucrcode=="26D" | ucrcode=="26E" | ucrcode=="23A" | ucrcode=="23B" | ucrcode=="23C"
    | ucrcode=="23D" | ucrcode=="23E" | ucrcode=="23F" | ucrcode=="23G" | ucrcode=="23H"
    | ucrcode=="240" | ucrcode=="120" | ucrcode=="280";


 keep if prop==1 & incdate~="";
 collapse (mean) prop_val, by (ori incnum incdate);

 save tmp, replace;
 clear;

*******************************************************************************************;
*I am now going to manipulate the offender data so there is one record per incident.
*I will create a measure that takes on a value of 1 if any of the offenders were
*juveniles.
*******************************************************************************************;

use V5003 V5004 V5007 if 
    V5003=="ID0100200" | V5003=="UT0060300" |
    V5003=="UT0030100" | V5003=="ID0140200" |
    V5003=="ID0420200" | V5003=="UT0180500" |
    V5003=="UT0182500" | V5003=="SC0230200" |
    V5003=="CO0010500" | V5003=="IA0070300" |
    V5003=="CO0010100" | V5003=="CO0210100" |
    V5003=="CO0300400" | V5003=="ID0010100" |
    V5003=="IA0570100" | V5003=="IA0770300" |
    V5003=="IA0820200" | V5003=="MA0071800" |
    V5003=="MA0146000" | V5003=="OH0570200" |
    V5003=="OH0770100" | V5003=="OHCIP0000" |
    V5003=="SC0400100" | V5003=="TX2270100" |
    V5003=="UT0250600" | V5003=="VA1160000" |
    V5003=="IA0520200" | V5003=="ND0510200" |
    V5003=="ND0090200" using ${dnibrs}\nibrs`1'_off.dta;

  rename V5003 ori;
  rename V5004 incnum;
  rename V5007 oage;
  gen juvoff=oage>=5 & oage<18;
  collapse (max) juvoff, by(ori incnum);
  keep if juvoff==1;

mmerge ori incnum using tmp.dta, type(n:n) umatch(ori incnum) 
   unmatched(master);

*I want to make sure that I only keep crimes with property values.;

 drop if prop_val<1 | juvoff~=1 | incdate=="";
*1 is a missing value code. I keep only incidents with positive reported property losses.;

 collapse (mean) prop_val, by(ori incnum incdate);

 compress;
 doub2flt _all;
 desc;
 
 save ${dcrime}\prop_cost`1'.dta, replace;
 clear;
 
 
end;

*  prop_cost 95;
*  prop_cost 96;
*  prop_cost 97;
*  prop_cost 98;
*  prop_cost 99;

  clear;
  use ${dcrime}\prop_cost95.dta;
  for num 96/99: append using "${dcrime}\prop_costX";

*Rarely the information is recorded in multiple years.  The next lines take care of this.;

 gen year=real(substr(incdate,1,4));
   label variable year "year of incident";
 gen month=real(substr(incdate,5,2));
   label variable month "month of incident";
 gen day=real(substr(incdate,7,2));
   label variable day "day of incident";



    gen str20 city="";
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";


**This drops out the relevant observations from my sample.;

  drop if city=="Akron, OH" & year<1999;
  drop if city=="Anderson, SC" & year==1995 & (month==11|month==12);
  drop if city=="Aurora, CO" & year<1997;
  drop if city=="Austin, TX" & year<1998;
  drop if city=="Beaufort, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Boise, ID" & year<1995 ;
  drop if city=="Cedar Rapids, IA" & year<1999;
  drop if city=="Charleston, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Cincinnati, OH" & year<1998;
  drop if city=="Clarksville, TN" & year<1998;
  drop if city=="Colorado Springs, CO" & year<1997;
  drop if city=="Columbia, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Council Bluffs, IA" & year<1998;
  drop if city=="Davenport, IA" & year==1996 & month==7;
  drop if city=="Dayton, OH" & year<1998;
  drop if city=="Des Moines, IA" & year<1995;
  drop if city=="Florence, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Greenville, SC" & year<1995;
  drop if city=="Jackson, MI" & year<1997;
  drop if city=="Lakewood, CO" & year<1997;
  drop if city=="Myrtle Beach, SC" & year==1995 & (month==11|month==12);
  drop if city=="Newport News, VA" & (year<1998 | (year==1998 & month<7));
  drop if city=="Orangeburg, SC" & year==1995 & (month==11|month==12);
  drop if city=="Petersburg, VA" & ((year==1995 & month<10)|(year==1999 & month==6));
  drop if city=="Provo, UT" & year<1995;
  drop if city=="Sandy, UT" & year<1995;
  drop if city=="Sioux City, IA" & year<1995;
  drop if city=="Southfield, MI" & (year<1996 | (year==1996 & month<5)); 
  drop if city=="Spartanburg, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Springfield, MA" & (year<1996 | (year==1996 & month<6));
  drop if city=="Sterling Heights, MI" & year==1995 & month<3;
  drop if city=="Waterloo, IA" & ((year==1996 & month<8) | year<1996);
  drop if city=="West Valley, UT" & ((year==1998 & month<8) | year<1998);
  drop if city=="Westminster, CO" & ((year==1999 & month==1) | (year==1998 & month==12)
     | (year==1997 & month>3) | year<1997);
  drop if city=="Worcester, MA" & year<1995;
  drop if city=="Idaho Falls, ID" & year<1995;
  drop if city=="Nampa, ID" & year<1995;
  drop if city=="Twin Falls, ID" & year<1995;
  drop if city=="Layton, UT" & ((year==1999 & month>=3 & month<=5) | (year==1998 & month>=7)
     | (year==1996 & month==9) | (year==1995 & month>=7 & month<=8) | (year==1995 & month<9)
     | year<1995);
  drop if city=="Logan, UT" & ((year==1999 & month==12) | (year==1998 & month>=11) | year<1995);
  drop if city=="Nampa, ID" & (year==1995 & (month==11 | month==12));
  drop if city=="Iowa City, IA" & (year<1996 | (year==1996 & month<8)); **Calendar data missing 1995/1996;
  drop if city=="Minot, ND" & (year==1995 & (month==11 | month==12));
  drop if city=="Fargo, ND" & year<1995;

*******************************;
*Mean property value cost of cities in my sample.;
*******************************;

 sum;


log close;

